==> mediawiki-1.6.12.tbz: www/mediawiki/languages/MessagesCv.php <==
<?php

/* private */ $wgAllMessagesCv = array(

'Monobook.js' => '/* tooltips and access keys */
ta = new Object();
ta[\'pt-userpage\'] = new Array(\'.\',\'Пользователь страници\');
ta[\'pt-anonuserpage\'] = new Array(\'.\',\'The user page for the ip you\'re editing as\');
ta[\'pt-mytalk\'] = new Array(\'n\',\'My talk page\');
ta[\'pt-anontalk\'] = new Array(\'n\',\'Discussion about edits from this ip address\');
ta[\'pt-preferences\'] = new Array(\'\',\'Настройкӑсем\');
ta[\'pt-watchlist\'] = new Array(\'l\',\'The list of pages you\'re monitoring for changes.\');
ta[\'pt-mycontris\'] = new Array(\'y\',\'List of my contributions\');
ta[\'pt-login\'] = new Array(\'o\',\'You are encouraged to log in, it is not mandatory however.\');
ta[\'pt-anonlogin\'] = new Array(\'o\',\'You are encouraged to log in, it is not mandatory however.\');
ta[\'pt-logout\'] = new Array(\'o\',\'Log out\');
ta[\'ca-talk\'] = new Array(\'t\',\'Статьяна сӳтсе явасси\');
ta[\'ca-edit\'] = new Array(\'e\',\'Эсир ку страницӑна тӳрлетме пултаратӑр. Тархасшӑн ҫырса хӑваричен страницӑ мӗнле пулассине пӑхӑр.\');
ta[\'ca-addsection\'] = new Array(\'+\',\'Кӗске ӑнлантару хушма пултаратӑр.\');
ta[\'ca-viewsource\'] = new Array(\'e\',\'Ку страницӑна эсир улӑштарма пултараймастӑр. Ӑна мӗнле ҫырнине кӑна пӑхма пултаратӑр.\');
ta[\'ca-history\'] = new Array(\'h\',\'Past versions of this page.\');
ta[\'ca-protect\'] = new Array(\'=\',\'Улӑшратусенчен сыхласси\');
ta[\'ca-delete\'] = new Array(\'d\',\'Страницӑна кӑларса пӑрахмалли\');
ta[\'ca-undelete\'] = new Array(\'d\',\'Restore the edits done to this page before it was deleted\');
ta[\'ca-move\'] = new Array(\'m\',\'Страницӑна урӑх ҫӗре куҫарасси\');
ta[\'ca-nomove\'] = new Array(\'\',\'Эсир ку страницӑна урӑх ҫӗре куҫараймастӑр\');
ta[\'ca-watch\'] = new Array(\'w\',\'Ку страницӑ хыҫҫӑн сӑнама пуҫласси\');
ta[\'ca-unwatch\'] = new Array(\'w\',\'Ку страницӑ хыҫҫӑн урӑх сӑнамалла мар\');
ta[\'search\'] = new Array(\'f\',\'Search this wiki\');
ta[\'p-logo\'] = new Array(\'\',\'Тӗп страницӑ\');
ta[\'n-mainpage\'] = new Array(\'z\',\'Visit the Main Page\');
ta[\'n-portal\'] = new Array(\'\',\'About the project, what you can do, where to find things\');
ta[\'n-currentevents\'] = new Array(\'\',\'Find background information on current events\');
ta[\'n-recentchanges\'] = new Array(\'r\',\'The list of recent changes in the wiki.\');
ta[\'n-randompage\'] = new Array(\'x\',\'Load a random page\');
ta[\'n-help\'] = new Array(\'\',\'The place to find out.\');
ta[\'n-sitesupport\'] = new Array(\'\',\'Support us\');
ta[\'t-whatlinkshere\'] = new Array(\'j\',\'List of all wiki pages that link here\');
ta[\'t-recentchangeslinked\'] = new Array(\'k\',\'Recent changes in pages linked from this page\');
ta[\'feed-rss\'] = new Array(\'\',\'RSS feed for this page\');
ta[\'feed-atom\'] = new Array(\'\',\'Atom feed for this page\');
ta[\'t-contributions\'] = new Array(\'\',\'View the list of contributions of this user\');
ta[\'t-emailuser\'] = new Array(\'\',\'Send a mail to this user\');
ta[\'t-upload\'] = new Array(\'u\',\'Upload images or media files\');
ta[\'t-specialpages\'] = new Array(\'q\',\'List of all special pages\');
ta[\'ca-nstab-main\'] = new Array(\'c\',\'View the content page\');
ta[\'ca-nstab-user\'] = new Array(\'c\',\'View the user page\');
ta[\'ca-nstab-media\'] = new Array(\'c\',\'View the media page\');
ta[\'ca-nstab-special\'] = new Array(\'\',\'This is a special page, you can\'t edit the page itself.\');
ta[\'ca-nstab-wp\'] = new Array(\'a\',\'View the project page\');
ta[\'ca-nstab-image\'] = new Array(\'c\',\'View the image page\');
ta[\'ca-nstab-mediawiki\'] = new Array(\'c\',\'View the system message\');
ta[\'ca-nstab-template\'] = new Array(\'c\',\'View the template\');
ta[\'ca-nstab-help\'] = new Array(\'c\',\'View the help page\');
ta[\'ca-nstab-category\'] = new Array(\'c\',\'View the category page\');',

'january' => 'Кăрлач',
'jan' => 'Кăр',
'trackbackremove' => ' ([$1 кăларса пăрах])',
'history_short' => 'Истори',
'deletedrev' => '[кăларса пăрахнă]',
'ancientpages' => 'Чи кивĕ статьясем',
'editingcomment' => '$1 тӳрлетни (кӗске анлантарӑвӗ)',
'servertime' => 'Сервер вăхăчě',
'listingcontinuesabbrev' => '(малалли)',
'show' => 'кăтартмалла',
'talkpagemoved' => 'Сӳтсе явмалли страницăн ятне те улăштартăмăр.',
'textboxsize' => 'Тӳрлетни',
'editing' => '$1 тӳрлетни',
'uploadedfiles' => 'Кĕртнĕ файлсем',
'hide' => 'кăтартмалла мар',
'and' => 'тата',
'qbspecialpages' => 'Ятарлӑ страницӑсем',
'showhideminor' => 'кăштах кăна тунă тӳрлетӳсене $1 | ботсене $2  | системăра палăртăннă пользовательсене $3 | тěрěсленě тӳрлетӳсене $4',
'helppage' => '{{ns:project}}:Пулăшу',
'uploaddisabled' => 'Каçарăр та сайта халĕ нимĕн те кĕртме юрамаст.',
'next' => 'тепěр',
'ipbreason' => 'Сăлтавĕ',
'previewnote' => 'Ку страницăна халлěхе çырса хуман. Эсир ку страницă мěнле пулассине кăна куратăр!!',
'editingsection' => '$1 тӳрлетни (статья разделě)',
'august' => 'Çурла',
'edithelp' => 'Улшăнусене кĕртме пулăшакан пулăшу',
'others' => 'ыттисем',
'jumptonavigation' => 'навигаци',
'createarticle' => 'Çĕнĕ статья çыр',
'aboutsite' => '{{SITENAME}} çинчен',
'templatesused' => 'Ку страница çинче усă курнă шаблонсем:',
'dec' => 'Раш',
'permalink' => 'Яланхи вырăн',
'tooltip-watch' => 'Çак страницăна пăхса тăмаллисем шутне хуш [alt-w]',
'rightslogtext' => 'Ку пользовательсен прависене улăштарниссен журналě',
'nextpage' => 'Тепěр страницă ($1)',
'undeleterevisions' => 'Архивра пурĕ $1 верси',
'allpages' => 'Пěтěм страницăсем',
'watchthis' => 'Ку страницăна кěртекен  улшăнусем  хыççăн сăнамалла',
'nstab-special' => 'Ятарлă',
'newpages' => 'Çěнě страницăсем',
'nstab-help' => 'пулăшу',
'tuesday' => 'Ытларикун',
'nstab-user' => 'Хутшăнакан страници',
'go' => 'Куç',
'nviews' => '$1 хут пăхнă',
'newpassword' => 'Çěнě пароль',
'monday' => 'Тунтикун',
'specialpages' => 'Ятарлă страницăсем',
'specialpage' => 'Ятарлă страницă',
'printableversion' => 'Пичетлемелли верси',
'edithelppage' => '{{ns:project}}:Улшăнусене кĕртме пулăшакан пулăшу',
'unblocklogentry' => '«$1» блокировкăран кăларнă',
'rclinks' => 'Юлашки $2 кун хушшинче тунă $1 улшăнусене кăтартмалла<br />$3',
'linktrail' => '/^([a-zа-яĕçăӳ"»]+)(.*)$/sDu',
'delete_and_move' => 'Кăларса пăрахса куçарасси',
'1movedto2' => '$1 $2 çине куçарнă',
'mainpage' => 'Тĕп страницă',
'laggedslavemode' => 'Асăрхăр! Страница çинче юлашки улшăнусене кăтартмасăр пултарнă.',
'movepage' => 'Страницăна куçарнă',
'sitesupport' => 'Пожертвованисем',
'undelete' => 'Кăларса пăрахнă страницăсене пăх',
'talk' => 'Сӳтсе явасси',
'jun' => 'Çěр',
'uploadlog' => 'Файлсене кĕртнин логĕ',
'thursday' => 'Кĕçнерникун',
'lastmodified' => 'Ку страницăна юлашки улăштарнă вăхăт: $1.',
'toc' => 'Тупмалли',
'rights' => 'Тума пултарать:',
'allmessagesfilter' => 'Regular expression filter:',
'oct' => 'Юпа',
'undeletebtn' => 'Каялла тавăр!',
'mar' => 'Пуш',
'rcnote' => 'Юлашки <strong>$2</strong> кун хушшинчи <strong>$1</strong> улшăнусем. Халě пěтěмпе  <strong>{{NUMBEROFARTICLES}}</strong> статья.',
'whatlinkshere' => 'Кунта килекен ссылкăсем',
'currentevents' => 'Хыпарсем',
'currentevents-url' => 'Хыпарсем',
'oldpassword' => 'Кивě пароль',
'uncategorizedcategories' => 'Каталога кĕртмен категорисем',
'december' => 'Раштав',
'talkpagenotmoved' => 'Сӳтсе явмалли страницăн ятне улăштарма пултараймарăмăр.',
'unblocklink' => 'блокировкăран кăлар',
'july' => 'Утă',
'may' => 'Çу',
'rollbackfailed' => 'Каялла куçарнă çухна йăнăш тухнă',
'deadendpages' => 'Ниăçта та урăх ертмен страницăсем',
'histfirst' => 'Пĕрремĕш',
'november' => 'Чӳк',
'uncategorizedpages' => 'Каталогсăр страницăсем',
'uclinks' => 'Юлашки $1 улшăнусене пăх; юлашки $2 кун хушшинче тунисене пăх.',
'recentchangeslinked' => 'Çыхăннă улшăнусем',
'delete' => 'Кăларса пăрахасси',
'toolbox' => 'Ĕç хатĕрĕсем',
'pagemovedsub' => 'Куçарас ěç тěрěс иртрě',
'minoredit' => 'Кунта пěчěк улшăнусем кăна кěртнě',
'aug' => 'Çур',
'upload' => 'Файла кĕртесси',
'sysoptitle' => 'Кун валли администратор прависем кирлě',
'ilsubmit' => 'Шырамалла',
'linkprefix' => '/^(.*?)([a-zA-Z\x80-\xff«"]+)$/sD',
'spheading' => 'Пěтěм пользовательсем валли ятарлă страницăсем',
'recentchanges' => 'Юлашки улшăнусем',
'imagelist' => 'Ӳкерчěксен списокě',
'nextrevision' => 'Çěнěрех верси→',
'aboutpage' => '{{ns:project}}:çинчен',
'unblockip' => 'IP-адреса блокировкăран калар',
'rows' => 'Йěркесем',
'rollback' => 'Тÿрлетÿсене каялла куçарасси',
'june' => 'Çěртме',
'otherlanguages' => 'Урăх чěлхесем',
'apr' => 'Ака',
'newpageletter' => 'Ç',
'notargettitle' => 'Тĕллевне кăтартман',
'category' => 'Категори',
'history' => 'Истори',
'editthispage' => 'Страницăна тӳрлетесси',
'uctop' => ' (пуçламăш)',
'friday' => 'Эрнекун',
'data' => 'Кун',
'undeletedarticle' => '«[[$1]]» каялла тавăрнă',
'deletepage' => 'Кăларса парахнă статьясем',
'underline-always' => 'Яланах',
'randompage' => 'Ăнсăртран илнě страницă',
'jumptosearch' => 'Шырав',
'nov' => 'Чӳк',
'october' => 'Юпа',
'talkpage' => 'Сӳтсе явасси',
'categories' => 'Категорисем',
'hidetoc' => 'кӑтартмалла мар',
'april' => 'Ака',
'listusers' => 'Хутшăнакансен списокĕ',
'ignorewarnings' => 'Асăрхаттарусене шута илмелле мар',
'files' => 'Файлсем',
'previousrevision' => '&larr;Малтанхи верси',
'histlast' => 'Юлашки',
'march' => 'Пуш',
'linklistsub' => '(ссылкăсен списокĕ)',
'undeletedrevisions' => '$1 кăларса пăрахнă тӳрлетӳсене каялла тавăрнă',
'undelete_short1' => 'Пĕр тӳрлетĕве каялла тавăр',
'tooltip-search' => 'Шырав [alt-f]',
'may_long' => 'Çу',
'rclistfrom' => 'Юлашки улшăнусене $1 вăхăтран пуçласа кăтартнă',
'allpagesnext' => 'Тепěр',
'localtime' => 'Вырăнти вăхăт',
'undeletearticle' => 'Кăларса парахнă страницăна каялла тавăр',
'edit' => 'Тӳрлетӳ',
'numedits' => 'Улшăнусен шучĕ (статьясем): $1',
'tooltip-save' => 'Тӳрлетӳсене астуса хăвармалла [alt-s]',
'search' => 'Шырасси',
'jul' => 'Утă',
'showingresults' => 'Аяларах эсир <b>#$2</b> пуçласа кăтартнă <b>$1</b> йĕркене куратăр.',
'rollback_short' => 'Каялла куçарасси',
'thumbnail-more' => 'Пысăклатмалли',
'september' => 'Авăн',
'undelete_short' => '$1 тӳрлетӳсене каялла тавăр',
'help' => 'Пулăшу',
'sep' => 'Авн',
);


?>

==> mediawiki-1.7.3.tbz: www/mediawiki/languages/MessagesCv.php <==
<?php

global $wgAllMessagesCv;
$wgAllMessagesCv = array(

'Monobook.js' => '/* tooltips and access keys */
var ta = new Object();
ta[\'pt-userpage\'] = new Array(\'.\',\'Пользователь страници\');
ta[\'pt-anonuserpage\'] = new Array(\'.\',\'The user page for the ip you\'re editing as\');
ta[\'pt-mytalk\'] = new Array(\'n\',\'My talk page\');
ta[\'pt-anontalk\'] = new Array(\'n\',\'Discussion about edits from this ip address\');
ta[\'pt-preferences\'] = new Array(\'\',\'Настройкӑсем\');
ta[\'pt-watchlist\'] = new Array(\'l\',\'The list of pages you\'re monitoring for changes.\');
ta[\'pt-mycontris\'] = new Array(\'y\',\'List of my contributions\');
ta[\'pt-login\'] = new Array(\'o\',\'You are encouraged to log in, it is not mandatory however.\');
ta[\'pt-anonlogin\'] = new Array(\'o\',\'You are encouraged to log in, it is not mandatory however.\');
ta[\'pt-logout\'] = new Array(\'o\',\'Log out\');
ta[\'ca-talk\'] = new Array(\'t\',\'Статьяна сӳтсе явасси\');
ta[\'ca-edit\'] = new Array(\'e\',\'Эсир ку страницӑна тӳрлетме пултаратӑр. Тархасшӑн ҫырса хӑваричен страницӑ мӗнле пулассине пӑхӑр.\');
ta[\'ca-addsection\'] = new Array(\'+\',\'Кӗске ӑнлантару хушма пултаратӑр.\');
ta[\'ca-viewsource\'] = new Array(\'e\',\'Ку страницӑна эсир улӑштарма пултараймастӑр. Ӑна мӗнле ҫырнине кӑна пӑхма пултаратӑр.\');
ta[\'ca-history\'] = new Array(\'h\',\'Past versions of this page.\');
ta[\'ca-protect\'] = new Array(\'=\',\'Улӑшратусенчен сыхласси\');
ta[\'ca-delete\'] = new Array(\'d\',\'Страницӑна кӑларса пӑрахмалли\');
ta[\'ca-undelete\'] = new Array(\'d\',\'Restore the edits done to this page before it was deleted\');
ta[\'ca-move\'] = new Array(\'m\',\'Страницӑна урӑх ҫӗре куҫарасси\');
ta[\'ca-nomove\'] = new Array(\'\',\'Эсир ку страницӑна урӑх ҫӗре куҫараймастӑр\');
ta[\'ca-watch\'] = new Array(\'w\',\'Ку страницӑ хыҫҫӑн сӑнама пуҫласси\');
ta[\'ca-unwatch\'] = new Array(\'w\',\'Ку страницӑ хыҫҫӑн урӑх сӑнамалла мар\');
ta[\'search\'] = new Array(\'f\',\'Search this wiki\');
ta[\'p-logo\'] = new Array(\'\',\'Тӗп страницӑ\');
ta[\'n-mainpage\'] = new Array(\'z\',\'Visit the Main Page\');
ta[\'n-portal\'] = new Array(\'\',\'About the project, what you can do, where to find things\');
ta[\'n-currentevents\'] = new Array(\'\',\'Find background information on current events\');
ta[\'n-recentchanges\'] = new Array(\'r\',\'The list of recent changes in the wiki.\');
ta[\'n-randompage\'] = new Array(\'x\',\'Load a random page\');
ta[\'n-help\'] = new Array(\'\',\'The place to find out.\');
ta[\'n-sitesupport\'] = new Array(\'\',\'Support us\');
ta[\'t-whatlinkshere\'] = new Array(\'j\',\'List of all wiki pages that link here\');
ta[\'t-recentchangeslinked\'] = new Array(\'k\',\'Recent changes in pages linked from this page\');
ta[\'feed-rss\'] = new Array(\'\',\'RSS feed for this page\');
ta[\'feed-atom\'] = new Array(\'\',\'Atom feed for this page\');
ta[\'t-contributions\'] = new Array(\'\',\'View the list of contributions of this user\');
ta[\'t-emailuser\'] = new Array(\'\',\'Send a mail to this user\');
ta[\'t-upload\'] = new Array(\'u\',\'Upload images or media files\');
ta[\'t-specialpages\'] = new Array(\'q\',\'List of all special pages\');
ta[\'ca-nstab-main\'] = new Array(\'c\',\'View the content page\');
ta[\'ca-nstab-user\'] = new Array(\'c\',\'View the user page\');
ta[\'ca-nstab-media\'] = new Array(\'c\',\'View the media page\');
ta[\'ca-nstab-special\'] = new Array(\'\',\'This is a special page, you can\'t edit the page itself.\');
ta[\'ca-nstab-project\'] = new Array(\'a\',\'View the project page\');
ta[\'ca-nstab-image\'] = new Array(\'c\',\'View the image page\');
ta[\'ca-nstab-mediawiki\'] = new Array(\'c\',\'View the system message\');
ta[\'ca-nstab-template\'] = new Array(\'c\',\'View the template\');
ta[\'ca-nstab-help\'] = new Array(\'c\',\'View the help page\');
ta[\'ca-nstab-category\'] = new Array(\'c\',\'View the category page\');',

'january' => 'Кăрлач',
'jan' => 'Кăр',
'trackbackremove' => ' ([$1 кăларса пăрах])',
'history_short' => 'Истори',
'deletedrev' => '[кăларса пăрахнă]',
'ancientpages' => 'Чи кивĕ статьясем',
'editingcomment' => '$1 тӳрлетни (кӗске анлантарӑвӗ)',
'servertime' => 'Сервер вăхăчě',
'listingcontinuesabbrev' => '(малалли)',
'show' => 'кăтартмалла',
'talkpagemoved' => 'Сӳтсе явмалли страницăн ятне те улăштартăмăр.',
'textboxsize' => 'Тӳрлетни',
'editing' => '$1 тӳрлетни',
'uploadedfiles' => 'Кĕртнĕ файлсем',
'hide' => 'кăтартмалла мар',
'and' => 'тата',
'qbspecialpages' => 'Ятарлӑ страницӑсем',
'showhideminor' => 'кăштах кăна тунă тӳрлетӳсене $1 | ботсене $2  | системăра палăртăннă пользовательсене $3 | тěрěсленě тӳрлетӳсене $4',
'helppage' => '{{ns:project}}:Пулăшу',
'uploaddisabled' => 'Каçарăр та сайта халĕ нимĕн те кĕртме юрамаст.',
'next' => 'тепěр',
'ipbreason' => 'Сăлтавĕ',
'previewnote' => 'Ку страницăна халлěхе çырса хуман. Эсир ку страницă мěнле пулассине кăна куратăр!!',
'editingsection' => '$1 тӳрлетни (статья разделě)',
'august' => 'Çурла',
'edithelp' => 'Улшăнусене кĕртме пулăшакан пулăшу',
'others' => 'ыттисем',
'jumptonavigation' => 'навигаци',
'createarticle' => 'Çĕнĕ статья çыр',
'aboutsite' => '{{SITENAME}} çинчен',
'templatesused' => 'Ку страница çинче усă курнă шаблонсем:',
'dec' => 'Раш',
'permalink' => 'Яланхи вырăн',
'tooltip-watch' => 'Çак страницăна пăхса тăмаллисем шутне хуш [alt-w]',
'rightslogtext' => 'Ку пользовательсен прависене улăштарниссен журналě',
'nextpage' => 'Тепěр страницă ($1)',
'undeleterevisions' => 'Архивра пурĕ $1 верси',
'allpages' => 'Пěтěм страницăсем',
'watchthis' => 'Ку страницăна кěртекен  улшăнусем  хыççăн сăнамалла',
'nstab-special' => 'Ятарлă',
'newpages' => 'Çěнě страницăсем',
'nstab-help' => 'пулăшу',
'tuesday' => 'Ытларикун',
'nstab-user' => 'Хутшăнакан страници',
'go' => 'Куç',
'nviews' => '$1 хут пăхнă',
'newpassword' => 'Çěнě пароль',
'monday' => 'Тунтикун',
'specialpages' => 'Ятарлă страницăсем',
'specialpage' => 'Ятарлă страницă',
'printableversion' => 'Пичетлемелли верси',
'edithelppage' => '{{ns:project}}:Улшăнусене кĕртме пулăшакан пулăшу',
'unblocklogentry' => '«$1» блокировкăран кăларнă',
'rclinks' => 'Юлашки $2 кун хушшинче тунă $1 улшăнусене кăтартмалла<br />$3',
'linktrail' => '/^([a-zа-яĕçăӳ"»]+)(.*)$/sDu',
'delete_and_move' => 'Кăларса пăрахса куçарасси',
'1movedto2' => '$1 $2 çине куçарнă',
'mainpage' => 'Тĕп страницă',
'laggedslavemode' => 'Асăрхăр! Страница çинче юлашки улшăнусене кăтартмасăр пултарнă.',
'movepage' => 'Страницăна куçарнă',
'sitesupport' => 'Пожертвованисем',
'undelete' => 'Кăларса пăрахнă страницăсене пăх',
'talk' => 'Сӳтсе явасси',
'jun' => 'Çěр',
'uploadlog' => 'Файлсене кĕртнин логĕ',
'thursday' => 'Кĕçнерникун',
'lastmodified' => 'Ку страницăна юлашки улăштарнă вăхăт: $1.',
'toc' => 'Тупмалли',
'rights' => 'Тума пултарать:',
'allmessagesfilter' => 'Regular expression filter:',
'oct' => 'Юпа',
'undeletebtn' => 'Каялла тавăр!',
'mar' => 'Пуш',
'rcnote' => 'Юлашки <strong>$2</strong> кун хушшинчи <strong>$1</strong> улшăнусем. Халě пěтěмпе  <strong>{{NUMBEROFARTICLES}}</strong> статья.',
'whatlinkshere' => 'Кунта килекен ссылкăсем',
'currentevents' => 'Хыпарсем',
'currentevents-url' => 'Хыпарсем',
'oldpassword' => 'Кивě пароль',
'uncategorizedcategories' => 'Каталога кĕртмен категорисем',
'december' => 'Раштав',
'talkpagenotmoved' => 'Сӳтсе явмалли страницăн ятне улăштарма пултараймарăмăр.',
'unblocklink' => 'блокировкăран кăлар',
'july' => 'Утă',
'may' => 'Çу',
'rollbackfailed' => 'Каялла куçарнă çухна йăнăш тухнă',
'deadendpages' => 'Ниăçта та урăх ертмен страницăсем',
'histfirst' => 'Пĕрремĕш',
'november' => 'Чӳк',
'uncategorizedpages' => 'Каталогсăр страницăсем',
'uclinks' => 'Юлашки $1 улшăнусене пăх; юлашки $2 кун хушшинче тунисене пăх.',
'recentchangeslinked' => 'Çыхăннă улшăнусем',
'delete' => 'Кăларса пăрахасси',
'toolbox' => 'Ĕç хатĕрĕсем',
'pagemovedsub' => 'Куçарас ěç тěрěс иртрě',
'minoredit' => 'Кунта пěчěк улшăнусем кăна кěртнě',
'aug' => 'Çур',
'upload' => 'Файла кĕртесси',
'sysoptitle' => 'Кун валли администратор прависем кирлě',
'ilsubmit' => 'Шырамалла',
'linkprefix' => '/^(.*?)([a-zA-Z\x80-\xff«"]+)$/sD',
'spheading' => 'Пěтěм пользовательсем валли ятарлă страницăсем',
'recentchanges' => 'Юлашки улшăнусем',
'imagelist' => 'Ӳкерчěксен списокě',
'nextrevision' => 'Çěнěрех верси→',
'aboutpage' => '{{ns:project}}:çинчен',
'unblockip' => 'IP-адреса блокировкăран калар',
'rows' => 'Йěркесем',
'rollback' => 'Тÿрлетÿсене каялла куçарасси',
'june' => 'Çěртме',
'otherlanguages' => 'Урăх чěлхесем',
'apr' => 'Ака',
'newpageletter' => 'Ç',
'notargettitle' => 'Тĕллевне кăтартман',
'category' => 'Категори',
'history' => 'Истори',
'editthispage' => 'Страницăна тӳрлетесси',
'uctop' => ' (пуçламăш)',
'friday' => 'Эрнекун',
'data' => 'Кун',
'undeletedarticle' => '«[[$1]]» каялла тавăрнă',
'deletepage' => 'Кăларса парахнă статьясем',
'underline-always' => 'Яланах',
'randompage' => 'Ăнсăртран илнě страницă',
'jumptosearch' => 'Шырав',
'nov' => 'Чӳк',
'october' => 'Юпа',
'talkpage' => 'Сӳтсе явасси',
'categories' => 'Категорисем',
'hidetoc' => 'кӑтартмалла мар',
'april' => 'Ака',
'listusers' => 'Хутшăнакансен списокĕ',
'ignorewarnings' => 'Асăрхаттарусене шута илмелле мар',
'files' => 'Файлсем',
'previousrevision' => '&larr;Малтанхи верси',
'histlast' => 'Юлашки',
'march' => 'Пуш',
'linklistsub' => '(ссылкăсен списокĕ)',
'undeletedrevisions' => '$1 кăларса пăрахнă тӳрлетӳсене каялла тавăрнă',
'undelete_short1' => 'Пĕр тӳрлетĕве каялла тавăр',
'tooltip-search' => 'Шырав [alt-f]',
'may_long' => 'Çу',
'rclistfrom' => 'Юлашки улшăнусене $1 вăхăтран пуçласа кăтартнă',
'allpagesnext' => 'Тепěр',
'localtime' => 'Вырăнти вăхăт',
'undeletearticle' => 'Кăларса парахнă страницăна каялла тавăр',
'edit' => 'Тӳрлетӳ',
'numedits' => 'Улшăнусен шучĕ (статьясем): $1',
'tooltip-save' => 'Тӳрлетӳсене астуса хăвармалла [alt-s]',
'search' => 'Шырасси',
'jul' => 'Утă',
'showingresults' => 'Аяларах эсир <b>#$2</b> пуçласа кăтартнă <b>$1</b> йĕркене куратăр.',
'rollback_short' => 'Каялла куçарасси',
'thumbnail-more' => 'Пысăклатмалли',
'september' => 'Авăн',
'undelete_short' => '$1 тӳрлетӳсене каялла тавăр',
'help' => 'Пулăшу',
'sep' => 'Авн',
);


?>
